@@ -395,6 +395,17 @@ class Extractor:
         return final_res
 
 
+    def extract_weapon(self, text):
+        res = re.search('[a-zA-Z]+[—\-－一–]*[0-9]+[a-zA-Z]*', text)
+        if not res:
+            res = re.search('[a-zA-Z]+[—\-－一–][a-zA-Z]+', text)
+            if not res:
+                res = re.search('[0-9]+[—\-－一–][0-9]+', text)
+        return res
+
+
+
+
 
 
 
@@ -455,9 +466,19 @@ class Extractor:
 
 if __name__ == '__main__':
     et = Extractor()
-    res = et.extract_reference_no("JR/T0025.15-－2018")
-    print(res)
+    count_all = 0
+    count = 0
+    with open("query_toolkits/weapon.txt", "r") as f:
+        for line in f:
+            count_all += 1
+            res = et.extract_weapon(line)
+            if not res:
+                count += 1
+                print(line)
+    print(count/count_all)
     exit(0)
+    res = et.extract_reference_no("银发〔2015〕324号/JR/T 0125-2015")
+    print(res)
     print(datetime.today())
     start = time.time()
     # text = "2021-03-0914:00开庭审理杨峰？"
